import React, { FC } from 'react';
import { View } from 'react-native';
import { StoryProgressBar } from '../../atoms';
import { ProgressBarTimer } from '../progressBarTimer';
import { ProgressBarHeaderModel } from '../progressBarTimer/progressBarTimerModels';
import { PercentageType } from '../models';

interface EnabledModel {
  onFinish?: () => void;
  forceCleanInterval?: boolean;
  size: number;
  time?: number;
}

interface EmptyModel {
  percentage: PercentageType;
  size: number;
}

const EmptyComponent: FC<EmptyModel> = ({ percentage, size }) => (
  <View style={{ width: `${size}%` }}>
    <StoryProgressBar percentage={percentage} />
  </View>
);

const EnabledComponent: FC<EnabledModel> = ({
  onFinish,
  forceCleanInterval,
  size,
  time,
}) => (
  <View style={{ width: `${size}%` }}>
    <ProgressBarTimer
      ProgressBarComponent={StoryProgressBar}
      timeInMilliseconds={time}
      onFinish={onFinish}
      forceCleanInterval={forceCleanInterval}
    />
  </View>
);


export const ProgressBarDynamicHeader: FC<ProgressBarHeaderModel> = ({
  onFinish,
  forceCleanInterval,
  positionPage,
  iterationsLength,
  progressBarDurationTime,
}) => {
  const listOfProgress = new Array(iterationsLength).fill(null).map((item, key) => {
    const hasActive = key + 1 === positionPage;
    const hasPrevious = key + 1 < positionPage;
    const size = (100 / iterationsLength) - 1;

    return hasActive
    // eslint-disable-next-line max-len
      ? <EnabledComponent key={key} forceCleanInterval={forceCleanInterval} onFinish={onFinish} size={size} time={progressBarDurationTime} />
      : hasPrevious
        ? <EmptyComponent key={key} percentage={100} size={size} />
        : <EmptyComponent key={key} percentage={0} size={size} />;
  });
  return (
    <View style={{ flexDirection: 'row', justifyContent: 'space-between' }}>
      {listOfProgress.map((Item) => Item)}
    </View>
  );
};
